.. -*- mode: rst; encoding: utf-8 -*-

Babel
=====

Babel is an integrated collection of utilities that assist in
internationalizing and localizing Python applications, with an emphasis on
web-based applications.

User Documentation
------------------

The user documentation explains some core concept of the library and gives
some information about how it can be used.

.. toctree::
   :maxdepth: 1

   intro
   installation
   locale
   dates
   numbers
   messages
   cmdline
   setup
   support

API Reference
-------------

The API reference lists the full public API that Babel provides.

.. toctree::
   :maxdepth: 2

   api/index

Additional Notes
----------------

.. toctree::
   :maxdepth: 2

   dev
   changelog
   license
